########################################################################################################
# Readme
########################################################################################################
# This R script provides the analysis underlying the paper
#    Henner Gimpel, Marcia Nien, Roland A. Grlitz (2013).
#    Quantifying the Quantified Self: A Study on the Motivations of Patients to Track Their Own Health. 
#    ICIS 2013 Proceedings (International Conference on Information Sys-tems. Milan, Italy)
#    Association for Information Systems (AIS).
# Please address comments and questions to henner.gimpel@kit.edu
# This script was prepared with R version 2.15.2

########################################################################################################
# Startup
########################################################################################################
rm(list = ls())                                             # remove all object from R workspace

install.packages("psych")                                   # install library for exploratory factor analysis. Required only once
library("psych")                                            # load library for exploratory factor analysis

install.packages("nFactors")                                # install library for parallel analysis. Required only once
library("nFactors")                                         # load library for parallel analysis

install.packages("multilevel")                              # install library for calculating Cronbach's Alpha. Required only once
library("multilevel")                                       # load library for calculating Cronbach's Alpha

install.packages("sem")                                     # install library for confirmatory factor analysis. Required only once
library("sem")                                              # load library for confirmatory factor analysis

install.packages("qgraph")                                  # install library to plot result of confirmatory factor analysis. Required only once
library("qgraph")                                           # load library to plot result of confirmatory factor analysis

install.packages("rpanel")                                  # install library to plot result of confirmatory factor analysis. Required only once
library("rpanel")                                           # load library to plot result of confirmatory factor analysis

install.packages("rms")                                     # install library for logistic regression models. Required only once
library("rms")                                              # load library for logistic regression models

install.packages("mediation")                               # install library for mediation analysis. Required only once
library("mediation")                                        # load library for mediation analysis

install.packages("sandwich")                                # install library for robust standard error estimates in mediation analysis. Required only once
library("sandwich")                                         # load library for robust standard error estimates in mediation analysis

path        <- ""                                           # set path for input data, if R was not started from the directory where the data is stored
input.file  <- "Gimpel_et_al._2013_-_QS_survey_data.csv"    # set file name for input data
data <- read.csv(paste(path, input.file, sep=""), sep=";")  # read data
rm(path, input.file)                                        # remove obsolete objects from memory

########################################################################################################
# Plausibility check on data
########################################################################################################

names(data)                                                 # list all variables included in the data set
summary(data)                                               # provide summary statistics for each variable

# Motivations not perfectly correlated?
items <- c("motivation.01", "motivation.02", "motivation.03", "motivation.04", "motivation.05", "motivation.06", "motivation.07", "motivation.08", "motivation.09", "motivation.10", "motivation.11", "motivation.12", "motivation.13", "motivation.14", "motivation.15", "motivation.16", "motivation.17", "motivation.18", "motivation.19", "motivation.20", "motivation.21", "motivation.22", "motivation.23", "motivation.24", "motivation.25", "motivation.26", "motivation.27", "motivation.28", "motivation.29", "motivation.30", "motivation.31")
corMat <- cor(data[,items])                                 # Calculate correlation matrix of motivations
for(i in 1:dim(corMat)[1]) corMat[i,i] <- NA                # set diagonal (equal to 1 by deifnition) to NA
min(corMat, na.rm=TRUE)                                     # View minimum of correlations
max(corMat, na.rm=TRUE)                                     # View maximum of correlations
round(corMat, 2)                                            # View all correlations
rm(i, corMat)                                               # remove obsolete objects from memory

########################################################################################################
# Exploratory factor analysis
########################################################################################################

####
# Determine number of factors to extracts
# Result following parallel analysis: 5 factors
items <- c("motivation.01", "motivation.02", "motivation.03", "motivation.04", "motivation.05", "motivation.06", "motivation.07", "motivation.08", "motivation.09", "motivation.10", "motivation.11", "motivation.12", "motivation.13", "motivation.14", "motivation.15", "motivation.16", "motivation.17", "motivation.18", "motivation.19", "motivation.20", "motivation.21", "motivation.22", "motivation.23", "motivation.24", "motivation.25", "motivation.26", "motivation.27", "motivation.28", "motivation.29", "motivation.30", "motivation.31")
fit <- principal(r = cor(data[,items]), rotate="none")                          # Calculate un-rotated PCA
plot(fit$values, type="b", col="black", xlab="Components", ylab="Eigenvalues")  # Plot eigenvalues of un-rotated PCA
par <- parallel(subject=dim(data)[1],var=length(items), rep=1000, cent=.05)     # Conduct parallel analysis
points(par$eigen$mevpea, type="b", col="red")                                   # Plot eigenvalues of parallel analysis
abline(h=1, col="blue")                                                         # Insert Eigenvalue = 1 (Kaiser criterion)

####
# Explore factor structure
fit <- principal(r = cor(data[,items]), nfactors=5, rotate="varimax")           # Calculate PCA with orthogonal rotation (Varimax) and 5 factors
print.psych(x=fit, cut=0.3999, sort=TRUE)                                       # Print output of PCA, omitting loadings < 0.4

# Drop items that have no major loading (all loadings <0.4) 
items <- items[!items=="motivation.22"]
items <- items[!items=="motivation.29"]

# Re-run factor analysis
fit <- principal(r = cor(data[,items]), nfactors=5, rotate="varimax")
print.psych(x=fit, cut=0.3999, sort=TRUE)

# Drop items with low communality (h2 < 0.4) 
items <- items[!items=="motivation.11"]
items <- items[!items=="motivation.12"]
items <- items[!items=="motivation.13"]
items <- items[!items=="motivation.27"]

# Re-run factor analysis
fit <- principal(r = cor(data[,items]), nfactors=5, rotate="varimax")
print.psych(x=fit, cut=0.3999, sort=TRUE)

# Drop items with major cross loading (cross loading > 0.4) 
items <- items[!items=="motivation.15"]
items <- items[!items=="motivation.21"]
items <- items[!items=="motivation.28"]
items <- items[!items=="motivation.24"]
items <- items[!items=="motivation.18"]

# Re-run factor analysis
fit <- principal(r = cor(data[,items]), nfactors=5, rotate="varimax")
print.psych(x=fit, cut=0.3999, sort=TRUE)

# Drop items that do not fit content-wise
items <- items[!items=="motivation.07"]

# Re-run factor analysis
fit <- principal(r = cor(data[,items]), nfactors=5, rotate="varimax")
print.psych(x=fit, cut=0.3999, sort=TRUE)

# Re-confirm 5 factor structure in reduced set of items
fit <- principal(r = cor(data[,items]), rotate="none")                          # Calculate un-rotated PCA
plot(fit$values, type="b", col="black", xlab="Components", ylab="Eigenvalues")  # Plot eigenvalues of un-rotated PCA
par <- parallel(subject=dim(data)[1],var=length(items), rep=1000, cent=.05)     # Conduct parallel analysis
points(par$eigen$mevpea, type="b", col="red")                                   # Plot eigenvalues of parallel analysis
abline(h=1, col="blue")                                                         # Insert Eigenvalue = 1 (Kaiser criterion)

rm(par)                                                                         # remove obsolete objects from memory

########################################################################################################
# Assess quality of exploratory factor analysis
########################################################################################################

####
# Content fit of 5 factor model -> yes
fit <- principal(r = cor(data[,items]), nfactors=5, rotate="varimax")
print.psych(x=fit, cut=0.3999, sort=TRUE)

####
# Content fit of 4 factor model -> worse than 5 factors (mixes self motivation and self optimization in factor 1)
fit <- principal(r = cor(data[,items]), nfactors=4, rotate="varimax")
print.psych(x=fit, cut=0.3999, sort=TRUE)

####
# Content fit of 6 factor model -> worse than 5 factors (major cross loadings and eigen-value of sixth component < 1)
fit <- principal(r = cor(data[,items]), nfactors=6, rotate="varimax")
print.psych(x=fit, cut=0.3999, sort=TRUE)
fit <- principal(r = cor(data[,items]), nfactors=6, rotate="none")
print.psych(x=fit, cut=0.3999, sort=TRUE)

####
# Cronbach's Alpha
# Self-Entertainment
cronbach(data[,c("motivation.03", "motivation.04", "motivation.05", "motivation.02", "motivation.01")])$Alpha    # Calculate Alpha
round(cor(data[,c("motivation.03", "motivation.04", "motivation.05", "motivation.02", "motivation.01")]), 3)     # Inspect pairwise correlations

# Self-Association
cronbach(data[,c("motivation.06", "motivation.08", "motivation.14", "motivation.23")])$Alpha                     # Calculate Alpha
round(cor(data[,c("motivation.06", "motivation.08", "motivation.14", "motivation.23")]), 3)                      # Inspect pairwise correlations

# Self-Design
cronbach(data[,c("motivation.25", "motivation.10", "motivation.26", "motivation.09", "motivation.20")])$Alpha    # Calculate Alpha
round(cor(data[,c("motivation.25", "motivation.10", "motivation.26", "motivation.09", "motivation.20")]), 3)     # Inspect pairwise correlations

# Self-Discipline -- Alpha only 0.678 
cronbach(data[,c("motivation.17", "motivation.19", "motivation.16")])$Alpha                                      # Calculate Alpha
round(cor(data[,c("motivation.17", "motivation.19", "motivation.16")]), 3)                                       # Inspect pairwise correlations

# Self-Healing
cronbach(data[,c("motivation.30", "motivation.31")])$Alpha                                                       # Calculate Alpha
round(cor(data[,c("motivation.17", "motivation.19", "motivation.16")]), 3)                                       # Inspect pairwise correlations

########################################################################################################
# Table 2. Rotated component matrix of the exploratory principal component analysis
########################################################################################################

fit <- principal(r = cor(data[,items]), nfactors=5, rotate="varimax")
print.psych(x=fit, cut=0.3999, sort=TRUE)                                # Print only major loadings
print.psych(x=fit, cut=0, sort=TRUE)                                     # Print all major loadings
# Each individual factor explains at least 10% of the total variance ("Proportion Var")
# All factors jointly explain more than 60% of the total variance ("Cumulative Var")
# All communalities > 40% (share of variance of an item variance that is explained by factors)
# No major cross loadings

rm(fit)                                                                         # remove obsolete objects from memory

########################################################################################################
# Confirmatory factor analysis
########################################################################################################

#####
# Specify model
covMat <- cov(data[,items])

my.model <- specifyModel()
F.self.entertainment -> motivation.03, lam01, NA
F.self.entertainment -> motivation.04, lam02, NA
F.self.entertainment -> motivation.05, lam03, NA
F.self.entertainment -> motivation.01, lam04, NA
F.self.entertainment -> motivation.02, lam05, NA
F.self.association   -> motivation.06, lam06, NA
F.self.association   -> motivation.08, lam07, NA
F.self.association   -> motivation.14, lam08, NA
F.self.association   -> motivation.23, lam09, NA
F.self.design        -> motivation.25, lam10, NA
F.self.design        -> motivation.10, lam11, NA
F.self.design        -> motivation.26, lam12, NA
F.self.design        -> motivation.09, lam13, NA
F.self.design        -> motivation.20, lam14, NA
F.self.discipline    -> motivation.17, lam15, NA
F.self.discipline    -> motivation.19, lam16, NA
F.self.discipline    -> motivation.16, lam17, NA
F.self.healing       -> motivation.30, lam18, NA
F.self.healing       -> motivation.31, lam19, NA
motivation.03 <-> motivation.03, e01, NA
motivation.04 <-> motivation.04, e02, NA
motivation.05 <-> motivation.05, e03, NA
motivation.01 <-> motivation.01, e04, NA
motivation.02 <-> motivation.02, e05, NA
motivation.06 <-> motivation.06, e06, NA
motivation.08 <-> motivation.08, e07, NA
motivation.14 <-> motivation.14, e08, NA
motivation.23 <-> motivation.23, e09, NA
motivation.25 <-> motivation.25, e10, NA
motivation.10 <-> motivation.10, e11, NA
motivation.26 <-> motivation.26, e12, NA
motivation.09 <-> motivation.09, e13, NA
motivation.20 <-> motivation.20, e14, NA
motivation.17 <-> motivation.17, e15, NA
motivation.19 <-> motivation.19, e16, NA
motivation.16 <-> motivation.16, e17, NA
motivation.30 <-> motivation.30, e18, NA
motivation.31 <-> motivation.31, e19, NA
F.self.entertainment <-> F.self.entertainment, NA, 1
F.self.association   <-> F.self.association,     NA, 1
F.self.design        <-> F.self.design,      NA, 1
F.self.discipline    <-> F.self.discipline,      NA, 1
F.self.healing       <-> F.self.healing,        NA, 1
F.self.entertainment <-> F.self.association, F.ent.com, NA
F.self.entertainment <-> F.self.design,  F.ent.opt, NA
F.self.entertainment <-> F.self.discipline,  F.ent.dis, NA
F.self.entertainment <-> F.self.healing,    F.ent.hea, NA
F.self.association   <-> F.self.design,  F.com.opt, NA
F.self.association   <-> F.self.discipline,  F.com.dis, NA
F.self.association   <-> F.self.healing,    F.com.hea, NA
F.self.design        <-> F.self.discipline,  F.opt.dis, NA
F.self.design        <-> F.self.healing,    F.opt.hea, NA
F.self.discipline    <-> F.self.healing,    F.dis.hea, NA

my.sem <- sem(model = my.model, S = covMat, N = nrow(data))                     # Estimate SEM
summary(my.sem, fit.indices=c("RMSEA"))                                                                 # Print SEM output numericall
qgraph(my.sem, minimum=0.4, esize=6, asize=3, edge.color="cornflowerblue")      # Plot SEM output graphically

rm(my.model, my.sem, covMat)                                                    # remove obsolete objects from memory

########################################################################################################
# Calculate factor scores for each respondent
########################################################################################################
fit <- principal(r = data[,items], nfactors=5, rotate="varimax", scores=TRUE)   # Re-calculate exploratory factor analysis
print.psych(x=fit, cut=0.4, sort=TRUE)                                          # Print and double-check result

factors <- c("self.entertainment", "self.association", "self.design", "self.discipline", "self.healing")

data[,factors] <- fit$scores                                                    # Attach factor scores to data frame

summary(data[,factors])                                                         # Print summary statistics to check result. 
                                                                                # Each factor score has to be mean-centered by construction

round(cor(data[,factors]), 3)                                                   # Analyze factor correlation to check result
                                                                                # Correlations have to be zero by contruction (orthogonal rotation)

rm(fit)                                                                         # remove obsolete objects from memory

########################################################################################################
# Table 3. Regression of the object of tracking on motivational factors
########################################################################################################

# Predict tracking of activity parameters by motivational factors in a logistic regression
data$object.activity <- 0
data$object.activity[data$object.phys_steps=="Yes" |
  data$object.phys_floors  =="Yes" |
  data$object.phys_bike=="Yes" |
  data$object.phys_run=="Yes" |
  data$object.phys_exerc=="Yes" |
  data$object.phys_other=="Yes"] <- 1
lrm(glm(object.activity ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data, family="binomial"))

# Predict tracking of body parameters by motivational factors in a logistic regression
data$object.body <- 0
data$object.body[data$object.body_stamina=="Yes" |
  data$object.body_musclestrength  =="Yes" |
  data$object.body_weight=="Yes" |
  data$object.body_bodymeasure=="Yes" |
  data$object.body_bloodpressure=="Yes" |
  data$object.body_heartrate=="Yes" |
  data$object.body_bodyfat=="Yes" |
  data$object.body_bodywater=="Yes" |
  data$object.body_BMI=="Yes" |
  data$object.body_other=="Yes"] <- 1
lrm(glm(object.body ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data, family="binomial"))

# Predict tracking of well being parameters by motivational factors in a logistic regression
data$object.well.being <- 0
data$object.well.being[data$object.well_being_mood=="Yes" |
  data$object.well_being_wellbeing  =="Yes" |
  data$object.well_being_sleeptime=="Yes" |
  data$object.well_being_sleepquality=="Yes" |
  data$object.well_being_dreams=="Yes" |
  data$object.well_being_other=="Yes"] <- 1
lrm(glm(object.well.being ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data, family="binomial"))

# Predict tracking of nutrition parameters by motivational factors in a logistic regression
data$object.nutrition<- 0
data$object.nutrition[data$object.nutrion_caloriesintake=="Yes" |
  data$object.nutrion_caloriesbalance  =="Yes" |
  data$object.nutrion_waterconsumption=="Yes" |
  data$object.nutrion_nutrsupp=="Yes" |
  data$object.nutrion_other=="Yes"] <- 1
lrm(glm(object.nutrition ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data, family="binomial"))

# Predict tracking of medical parameters by motivational factors in a logistic regression
data$object.medical <- 0
data$object.medical[  data$object.medical_medication=="Yes" |
  data$object.medical_dosis  =="Yes" |
  data$object.medical_symptoms=="Yes" |
  data$object.medical_bloodtest=="Yes" |
  data$object.medical_insulin=="Yes" |
  data$object.medical_bloodsugar=="Yes" |
  data$object.medical_healthstate=="Yes" |
  data$object.medical_other=="Yes"] <- 1
lrm(glm(object.medical ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data, family="binomial"))

# Predict tracking of environment parameters by motivational factors in a logistic regression
data$object.environment <- 0
data$object.environment[  data$object.environment_temp=="Yes" |
  data$object.environment_ozone  =="Yes" |
  data$object.environment_location=="Yes" |
  data$object.environment_atmosphereic=="Yes" |
  data$object.environment_rain=="Yes" |
  data$object.environment_clouds=="Yes" |
  data$object.environment_other=="Yes"] <- 1
lrm(glm(object.environment ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data, family="binomial"))

# Predict tracking of addiction parameters by motivational factors in a logistic regression
data$object.addiction <- 0
data$object.addiction[data$object.addictions_coffee=="Yes" |
  data$object.addictions_cigarettes	=="Yes" |
  data$object.addictions_alcohol=="Yes" |
  data$object.addictions_other=="Yes"] <- 1
lrm(glm(object.addiction ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data, family="binomial"))

# Predict tracking of relationship parameters by motivational factors in a logistic regression
data$object.relationships <- 0
data$object.relationships[  data$object.relationships_meetfreque=="Yes" |
  data$object.relationships_meetquality  =="Yes" |
  data$object.relationships_sex=="Yes" |
  data$object.relationships_other=="Yes"] <- 1
lrm(glm(object.relationships ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data, family="binomial"))

# Predict tracking of other parameters by motivational factors in a logistic regression
data$object.other <- 0
data$object.other[  data$object.other_finance=="Yes" |
  data$object.other_todo  =="Yes" |
  data$object.other_delay=="Yes" |
  data$object.other_other=="Yes"] <- 1
lrm(glm(object.other ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data, family="binomial"))

########################################################################################################
# Figure 1. Causal mediation analysis to assess criterion-related validity of the Five-Factor Frame-work of Self-Tracking Motivations
########################################################################################################
# Calculate and use logarithm of time spend on self tracking to account for outliers
data$time.daily.tracking.log <- log(data$activity.total.time.min.per.day+1)  

# Mediation analysis following procedure by Baron and Kenny (1986)
# Step 1: Establish direct effect
summary(lm(time.daily.tracking.log ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data))

# Step 2: Show that the initial variable is correlated with the mediator
summary(lm(time.daily.tracking.log ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data))

# Step 3: Show that the mediator affects the outcome variable
# and Step 4: Test whether their remains a direct effect
summary(lm(time.daily.tracking.log ~ self.entertainment + self.association + self.design + self.discipline + self.healing + activity.num.parameters.tracked, data=data))
# Result: Number of paramters partially mediates the effect of motivation on time for tracking

# Estimate total direct effect and mediation effect
med.fit <- lm(activity.num.parameters.tracked ~ self.entertainment + self.association + self.design + self.discipline + self.healing, data=data)
out.fit <- lm(time.daily.tracking.log ~ self.entertainment + self.association + self.design + self.discipline + self.healing + activity.num.parameters.tracked, data=data)
med.out <- mediate(med.fit, out.fit, treat = factors, mediator = "activity.num.parameters.tracked", robustSE = TRUE)
summary(med.out)
plot(med.out)

rm(med.fit, out.fit, med.out)                                                                          # remove obsolete objects from memory


########################################################################################################
# Calculate personality scores
########################################################################################################

# Define a function to recode text answers to numeric codes
replace.presonality.responses <- function(responses){
  responses <- paste(responses)
  responses[responses=="Strongly disagree"] <- 1
  responses[responses=="Disagree"]          <- 2
  responses[responses=="Neutral"]           <- 3
  responses[responses=="Agree"]             <- 4
  responses[responses=="Strongly agree"]    <- 5
  return(as.numeric(responses))
}

# Recode scores
personality.items <- c("personality.01", "personality.02", "personality.03", "personality.04", "personality.05", 
                       "personality.06", "personality.07", "personality.08", "personality.09", "personality.10")
data[,personality.items] <- apply(data[,personality.items], 2, replace.presonality.responses)

# Calculate Big 5 scores according to Rammstedt and John (2007)
data$extraversion      <- (6 - data$personality.01) + data$personality.06
data$agreeableness     <- data$personality.02 + (6 - data$personality.07)
data$conscientiousness <- (6 - data$personality.03) + data$personality.08
data$neuroticism       <- (6 - data$personality.04) + data$personality.09
data$openness          <- (6 - data$personality.05) + data$personality.10

personality.scores <- c("extraversion", "agreeableness", "conscientiousness", "neuroticism", "openness")
summary(data[,personality.scores])                   # Print summary statistics for each score. Scores range from 2 to 10

rm(replace.presonality.responses)                    # remove obsolete objects from memory

########################################################################################################
# Table 4. Correlation of motivational factors and personality traits
########################################################################################################
data$female <- ifelse(data$gender=="Female", 1, 0)          # Code females as unity, males as zero
data$female <- ifelse(data$gender=="N/A", NA, data$female)  # Code females as unity, males as zero

corMat <- cor(data[,c(factors, personality.scores, "age", "female")], use="pairwise.complete.obs")
round(corMat, 3)

round(as.numeric(cor.test(data$self.entertainment, data$extraversion)["p.value"]), 3)
round(as.numeric(cor.test(data$self.entertainment, data$agreeableness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.entertainment, data$conscientiousness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.entertainment, data$neuroticism)["p.value"]), 3)
round(as.numeric(cor.test(data$self.entertainment, data$openness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.entertainment, data$age)["p.value"]), 3)
round(as.numeric(cor.test(data$self.entertainment, data$female)["p.value"]), 3)       # 1% level

round(as.numeric(cor.test(data$self.association, data$extraversion)["p.value"]), 3)   # 5% level
round(as.numeric(cor.test(data$self.association, data$agreeableness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.association, data$conscientiousness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.association, data$neuroticism)["p.value"]), 3)    # 5% level
round(as.numeric(cor.test(data$self.association, data$openness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.association, data$age)["p.value"]), 3)
round(as.numeric(cor.test(data$self.association, data$femal)["p.value"]), 3)

round(as.numeric(cor.test(data$self.design, data$extraversion)["p.value"]), 3)
round(as.numeric(cor.test(data$self.design, data$agreeableness)["p.value"]), 3)       # 5% level
round(as.numeric(cor.test(data$self.design, data$conscientiousness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.design, data$neuroticism)["p.value"]), 3)         # 5% level
round(as.numeric(cor.test(data$self.design, data$openness)["p.value"]), 3)            # 5% level
round(as.numeric(cor.test(data$self.design, data$age)["p.value"]), 3)
round(as.numeric(cor.test(data$self.design, data$female)["p.value"]), 3)

round(as.numeric(cor.test(data$self.discipline, data$extraversion)["p.value"]), 3)
round(as.numeric(cor.test(data$self.discipline, data$agreeableness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.discipline, data$conscientiousness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.discipline, data$neuroticism)["p.value"]), 3)
round(as.numeric(cor.test(data$self.discipline, data$openness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.discipline, data$age)["p.value"]), 3)
round(as.numeric(cor.test(data$self.discipline, data$female)["p.value"]), 3)

round(as.numeric(cor.test(data$self.healing, data$extraversion)["p.value"]), 3)      # 5% level
round(as.numeric(cor.test(data$self.healing, data$agreeableness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.healing, data$conscientiousness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.healing, data$neuroticism)["p.value"]), 3)
round(as.numeric(cor.test(data$self.healing, data$openness)["p.value"]), 3)
round(as.numeric(cor.test(data$self.healing, data$age)["p.value"]), 3)
round(as.numeric(cor.test(data$self.healing, data$female)["p.value"]), 3)

rm(corMat)                                                                           # remove obsolete objects from memory

